#!/bin/sh

XMLLINT=xmllint
TOOLSDIR=`dirname $0`
CURDIR=`pwd`
cd $TOOLSDIR/..
BASEDIR=`pwd`
cd $CURDIR

SGML_CATALOG_FILES=$BASEDIR/docbook/xml/4.4/catalog.xml
export SGML_CATALOG_FILES

which $XMLLINT > /dev/null
RETVAL=$?
if [ $RETVAL -ne 0 ]; then
  echo "Error: $XMLLINT command required!"
  exit 1;
fi

$XMLLINT --xinclude --noout --postvalid --nonet --catalogs $*
exit $?
